@@ -1,11 +1,10 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 //! Implementation of the urls for the SAFE Network.
 
@@ -157,7 +156,7 @@ pub enum DataType {
     #[allow(missing_docs)]
     SafeKey = 0x00,
     #[allow(missing_docs)]
-    Bytes = 0x01,
+    File = 0x01,
     #[allow(missing_docs)]
     Register = 0x02,
 }
@@ -544,7 +543,7 @@ impl SafeUrl {
     /// returns SAFE data type
     pub fn data_type(&self) -> DataType {
         match self.address {
-            DataAddress::Bytes(_) => DataType::Bytes,
+            DataAddress::Bytes(_) => DataType::File,
             DataAddress::Register(_) => DataType::Register,
             DataAddress::SafeKey(_) => DataType::SafeKey,
         }
@@ -1403,7 +1402,7 @@ mod tests {
         assert_eq!(xor_name, url.xorname());
         assert_eq!(type_tag, url.type_tag());
         assert_eq!(Scope::Public, url.scope());
-        assert_eq!(DataType::Bytes, url.data_type());
+        assert_eq!(DataType::File, url.data_type());
         assert_eq!(ContentType::Raw, url.content_type());
         assert_eq!(Some(content_version), url.content_version());
         assert_eq!(query_string_v, url.query_string());
@@ -1500,7 +1499,7 @@ mod tests {
         )?;
 
         let url = SafeUrl::from_url(&xorurl)?;
-        assert_eq!(url.data_type(), DataType::Bytes);
+        assert_eq!(url.data_type(), DataType::File);
         Ok(())
     }
 
